<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2008 Joerg Weller <weller@flagbit.de>
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*  A copy is found in the textfile GPL.txt and important notices to the license
*  from the author is found in LICENSE.txt distributed with these scripts.
*
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

define('PATH_tslib', PATH_site.'typo3/sysext/cms/tslib/');

class tx_fbrealurltweak_urlgen {
	
	var $excludedDoktypes = array(6,7,199,254,255); // from URL generation excluded Doctypes
	

	/**
	 * generates a page url by typo3 frontend link render function
	 *
	 * @param int	 $id uid of the page
	 * @param int	 $lang uid of the language
	 */
	function generate_page_url($id,$lang=0){
		global $TYPO3_CONF_VARS;
 
		require_once(PATH_tslib.'class.tslib_fe.php');
 
		if(!is_object($GLOBALS['TSFE'])){
 
			require_once(PATH_t3lib.'class.t3lib_timetrack.php');
			if(!is_object($GLOBALS['TT'])){
				$GLOBALS['TT'] = new t3lib_timeTrack;
				$GLOBALS['TT']->start();
			}
 
			require_once(PATH_t3lib.'class.t3lib_page.php');
			require_once(PATH_t3lib.'class.t3lib_userauth.php');
			require_once(PATH_tslib.'class.tslib_feuserauth.php');
			require_once(PATH_t3lib.'class.t3lib_tstemplate.php');
			require_once(PATH_t3lib.'class.t3lib_cs.php');
			require_once(PATH_tslib.'class.tslib_content.php');
			require_once(PATH_tslib.'class.tslib_menu.php');
 
			$temp_TSFEclassName = t3lib_div::makeInstanceClassName('tslib_fe');
			$GLOBALS['TSFE'] = new $temp_TSFEclassName(
					$TYPO3_CONF_VARS,
					$id,
					0,
					'',
					'',
					'',
					'',
					''
				);
		}
 
		$GLOBALS['TSFE']->id=$id;
		$GLOBALS['TSFE']->initFEuser();
		
		// Look up the page
		$GLOBALS['TSFE']->sys_page = t3lib_div::makeInstance('t3lib_pageSelect');
		$GLOBALS['TSFE']->sys_page->init($GLOBALS['TSFE']->showHiddenPage);
		
		// If the page is not found (if the page is a sysfolder, etc), then return no URL, preventing any further processing which would result in an error page.
		$page = $GLOBALS['TSFE']->sys_page->getPage($id);
		
		if (count($page) == 0)
		    return '';
		
		// If the page is a shortcut, look up the page to which the shortcut references, and do the same check as above.
		if ($page['doktype']==4 && count($GLOBALS['TSFE']->getPageShortcut($page['shortcut'],$page['shortcut_mode'],$page['uid'])) == 0)
		    return '';
		
		// Spacer pages and sysfolders result in a page not found page too...
		if ($page['doktype'] == 199 || $page['doktype'] == 254)
		    return '';
		
		$GLOBALS['TSFE']->getPageAndRootline();
		$GLOBALS['TSFE']->initTemplate();
		$GLOBALS['TSFE']->forceTemplateParsing = 1;
		
		// Find the root template
		$GLOBALS['TSFE']->tmpl->start($GLOBALS['TSFE']->rootLine);
		
		// Fill the pSetup from the same variables from the same location as where tslib_fe->getConfigArray will get them, so they can be checked before this function is called
		$GLOBALS['TSFE']->sPre = $GLOBALS['TSFE']->tmpl->setup['types.'][$GLOBALS['TSFE']->type];     // toplevel - objArrayName
		$GLOBALS['TSFE']->pSetup = $GLOBALS['TSFE']->tmpl->setup[$GLOBALS['TSFE']->sPre.'.'];
		
		// If there is no root template found, there is no point in continuing which would result in a 'template not found' page and then call exit php. Then there would be no clickmenu at all.
		// And the same applies if pSetup is empty, which would result in a "The page is not configured" message.
		if (!$GLOBALS['TSFE']->tmpl->loaded || ($GLOBALS['TSFE']->tmpl->loaded && !$GLOBALS['TSFE']->pSetup))
		    return '';
		
		$GLOBALS['TSFE']->getConfigArray();		
			
		$GLOBALS['TSFE']->sys_language_uid=$lang;
		$GLOBALS['TSFE']->sys_page->sys_language_uid=$lang;
		$GLOBALS['TSFE']->config['config']['sys_language_uid']=$lang;
		
		$LangVar = $TYPO3_CONF_VARS ['EXTCONF'] ['realurl'] ['_DEFAULT']['pagePath']['languageGetVar'];
		
		$_GET[$LangVar]=$lang;
		if($lang && $LangVar) $params = "&".$LangVar."=".$lang;

		return is_array($GLOBALS['TSFE']->tmpl->linkData($GLOBALS['TSFE']->page,'',0,'','',$params));
	}

	/**
	* generates an array with enabled tree items by user editable languages
	*
	* @return array enabled tree items by user ediable languages
	*/		
	function getLangOverlayTreeItems(){
		
		// get page translations
		$query = $GLOBALS['TYPO3_DB']->exec_SELECTquery( 
						'pid, sys_language_uid', /* select */
						'pages_language_overlay', /* table */
						'1=1 '.
						t3lib_BEfunc::deleteClause('pages_language_overlay').
						t3lib_BEfunc::versioningPlaceholderClause('pages_language_overlay'), /* where */
						'', /* groupby */
						'pid', /* orderby */
						'', /* limit */
						'' /* index field */
					);
					
		$items = array();
		while($row=$GLOBALS['TYPO3_DB']->sql_fetch_assoc($query)){
			t3lib_BEfunc::workspaceOL('pages_language_overlay', $row, $GLOBALS['BE_USER']->workspace);
			$items[$row['pid']][$row['sys_language_uid']] = true;
		}		

		return $items;		
	}	
	
	
	/**
	 * Returns an array of available languages (to use for FlexForms)
	 *
	 * @param	integer		$id: If zero, the query will select all sys_language records from root level. If set to another value, the query will select all sys_language records that has a pages_language_overlay record on that page (and is not hidden, unless you are admin user)
	 * @param	boolean		$onlyIsoCoded: If set, only languages which are paired with a static_info_table / static_language record will be returned.
	 * @param	boolean		$setDefault: If set, an array entry for a default language is set.
	 * @param	boolean		$setMulti: If set, an array entry for "multiple languages" is added (uid -1)
	 * @return	array
	 * @access protected
	 */
	function getAvailableLanguages($id=0, $onlyIsoCoded=true, $setDefault=true, $setMulti=false)	{
		global $LANG, $TYPO3_DB, $BE_USER, $TCA, $BACK_PATH;

		t3lib_div::loadTCA ('sys_language');
		$flagAbsPath = t3lib_div::getFileAbsFileName($TCA['sys_language']['columns']['flag']['config']['fileFolder']);
		$flagIconPath = $BACK_PATH.'../'.substr($flagAbsPath, strlen(PATH_site));

		$output = array();
		$excludeHidden = $BE_USER->isAdmin() ? '1=1' : 'sys_language.hidden=0';
		$excludeHidden = 'sys_language.hidden=0';

		if ($id)	{
			$excludeHidden .= ' AND pages_language_overlay.deleted=0';
			$res = $TYPO3_DB->exec_SELECTquery(
				'DISTINCT sys_language.*',
				'pages_language_overlay,sys_language',
				'pages_language_overlay.sys_language_uid=sys_language.uid AND pages_language_overlay.pid='.intval($id).' AND '.$excludeHidden,
				'',
				'sys_language.title'
			);
		} else {
			$res = $TYPO3_DB->exec_SELECTquery(
				'sys_language.*',
				'sys_language',
				$excludeHidden,
				'',
				'sys_language.title'
			);
		}

		if ($setDefault) {
			$output[0]=array(
				'uid' => 0,
				'title' => strlen ($this->modSharedTSconfig['properties']['defaultLanguageLabel']) ? $this->modSharedTSconfig['properties']['defaultLanguageLabel'] : $LANG->getLL('defaultLanguage'),
				'ISOcode' => 'DEF',
				'flagIcon' => strlen($this->modSharedTSconfig['properties']['defaultLanguageFlag']) && @is_file($flagAbsPath.$this->modSharedTSconfig['properties']['defaultLanguageFlag']) ? $flagIconPath.$this->modSharedTSconfig['properties']['defaultLanguageFlag'] : null,
			);
		}

		if ($setMulti) {
			$output[-1]=array(
				'uid' => -1,
				'title' => $LANG->getLL ('multipleLanguages'),
				'ISOcode' => 'DEF',
				'flagIcon' => $flagIconPath.'multi-language.gif',
			);
		}

		while(TRUE == ($row = $TYPO3_DB->sql_fetch_assoc($res)))	{
			t3lib_BEfunc::workspaceOL('sys_language', $row);
			$output[$row['uid']]=$row;

			if ($row['static_lang_isocode'])	{
				$staticLangRow = t3lib_BEfunc::getRecord('static_languages',$row['static_lang_isocode'],'lg_iso_2');
				if ($staticLangRow['lg_iso_2']) {
					$output[$row['uid']]['ISOcode'] = $staticLangRow['lg_iso_2'];
				}
			}
			if (strlen ($row['flag'])) {
				$output[$row['uid']]['flagIcon'] = @is_file($flagAbsPath.$row['flag']) ? $flagIconPath.$row['flag'] : '';
			}

			if ($onlyIsoCoded && !$output[$row['uid']]['ISOcode']) unset($output[$row['uid']]);
		}

		return $output;
	}		
	
}

if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/fb_realurltweak/class.tx_fbrealurltweak_urlgen.php'])	{
	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/fb_realurltweak/class.tx_fbrealurltweak_urlgen.php']);
}

?>
